@@ -7,6 +7,7 @@
  */
 
 #include "emailindexer.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <QApplication>
 #include <QDebug>
@@ -84,13 +85,12 @@ void App::slotRootCollectionsFetched(KJob *kjob)
     QMutableListIterator<Akonadi::Collection> it(m_collections);
     while (it.hasNext()) {
         const Akonadi::Collection &c = it.next();
-        const QStringList mimeTypes = c.contentMimeTypes();
-        if (!c.contentMimeTypes().contains(QLatin1String("message/rfc822"))) {
+        if (!c.contentMimeTypes().contains("message/rfc822"_L1)) {
             it.remove();
         }
     }
 
-    if (m_collections.size()) {
+    if (!m_collections.isEmpty()) {
         indexNextCollection();
     } else {
         qDebug() << "No collections to index";
